@@ -1,9 +1,10 @@
 package DBIx::Class::Helper::ResultSet::AutoRemoveColumns;
+$DBIx::Class::Helper::ResultSet::AutoRemoveColumns::VERSION = '2.019003';
+use strict;
+use warnings;
 
 # ABSTRACT: Automatically remove columns from a ResultSet
 
-our $VERSION = '2.019001'; # VERSION
-
 use parent 'DBIx::Class::Helper::ResultSet::RemoveColumns', 'DBIx::Class';
 
 __PACKAGE__->mk_group_accessors(inherited => '_fetchable_columns');
@@ -66,7 +67,7 @@ DBIx::Class::Helper::ResultSet::AutoRemoveColumns - Automatically remove columns
 
 =head1 VERSION
 
-version 2.019001
+version 2.019003
 
 =head1 SYNOPSIS
 
@@ -146,7 +147,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
