@@ -1,9 +1,10 @@
 package DBIx::Class::Helper::ResultSet::RemoveColumns;
+$DBIx::Class::Helper::ResultSet::RemoveColumns::VERSION = '2.019003';
+use strict;
+use warnings;
 
 # ABSTRACT: Remove columns from a ResultSet
 
-our $VERSION = '2.019001'; # VERSION
-
 sub _resolved_attrs {
    my $self = $_[0];
 
@@ -33,7 +34,7 @@ DBIx::Class::Helper::ResultSet::RemoveColumns - Remove columns from a ResultSet
 
 =head1 VERSION
 
-version 2.019001
+version 2.019003
 
 =head1 SYNOPSIS
 
@@ -85,7 +86,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
