@@ -1,14 +1,10 @@
 package DBIx::Class::Helper::Schema::LintContents;
-
+$DBIx::Class::Helper::Schema::LintContents::VERSION = '2.019003';
 use strict;
 use warnings;
 
 use Scalar::Util 'blessed';
 
-# ABSTRACT: Check the data in your database match your constraints
-
-our $VERSION = '2.019000'; # VERSION
-
 sub null_check_source {
    my ($self, $source_name, $non_nullable_columns) = @_;
 
@@ -111,13 +107,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-DBIx::Class::Helper::Schema::LintContents - Check the data in your database match your constraints
+DBIx::Class::Helper::Schema::LintContents
 
 =head1 VERSION
 
-version 2.019000
+version 2.019003
 
 =head1 SYNOPSIS
 
@@ -234,7 +232,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
